<?php

declare(strict_types = 1);

namespace Drupal\brightcove\Services;

use Drupal\brightcove\Module;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Base functionality for a settings handler.
 */
abstract class SettingsBase {

  /**
   * Name of the storage.
   */
  protected const STORAGE = Module::NAME . '.settings';

  /**
   * Config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Initializes settings base.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Config factory.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * Helper function to save settings.
   *
   * @param string $key
   *   The key of the setting.
   * @param mixed $value
   *   The value of the setting.
   */
  protected function set(string $key, $value): void {
    $this->configFactory->getEditable(static::STORAGE)
      ->set($key, $value)
      ->save();
  }

}
